@@ -298,7 +298,7 @@ static void
 tokenize_free (json_token_t * token)
 {
     json_token_t * next;
-//    static int nfree;
+    static int nfree;
     next = token->child;
     if (next) {
 	if (! next->blessed) {
@@ -313,9 +313,11 @@ tokenize_free (json_token_t * token)
 	}
 	token->next = 0;
     }
-//    nfree++;
-//    fprintf (stderr, "Free %d %p\n", nfree, token);
-    Safefree (token);
+    if (! token->blessed) {
+	//nfree++;
+	//fprintf (stderr, "Free %d %p\n", nfree, token);
+	Safefree (token);
+    }
 }
 
 /* This is the entry point for validation. */
